pub struct HolepunchMessage {
pub msg_type: HolepunchMsgType,
pub addr: SocketAddr,
pub error_code: u32,
}Expand description
A parsed BEP 55 holepunch extension message.
Fields
msg_type: HolepunchMsgTypeMessage type.
addr: SocketAddrTarget/subject peer address.
error_code: u32Error code (meaningful only when msg_type == Error).
Implementations
Sourceimpl HolepunchMessage
impl HolepunchMessage
Sourcepub fn rendezvous(target: SocketAddr) -> Self
pub fn rendezvous(target: SocketAddr) -> Self
Create a Rendezvous message requesting the relay connect us to target.
Sourcepub fn connect(addr: SocketAddr) -> Self
pub fn connect(addr: SocketAddr) -> Self
Create a Connect message telling a peer to initiate a connection to addr.
Sourcepub fn error(addr: SocketAddr, error: HolepunchError) -> Self
pub fn error(addr: SocketAddr, error: HolepunchError) -> Self
Create an Error message for a failed rendezvous.
Sourcepub fn to_bytes(&self) -> Bytes
pub fn to_bytes(&self) -> Bytes
Serialize to binary payload (without the BEP 10 extension header).
Sourcepub fn from_bytes(data: &[u8]) -> Result<Self>
pub fn from_bytes(data: &[u8]) -> Result<Self>
Parse from binary payload (after BEP 10 extension header is stripped).
Errors
Returns an error if the data is too short or contains invalid fields.