#[repr(u32)]pub enum HolepunchError {
NoSuchPeer = 1,
NotConnected = 2,
NoSupport = 3,
NoSelf = 4,
}Expand description
Holepunch error codes (BEP 55).
Variants
NoSuchPeer = 1
The target endpoint is invalid.
NotConnected = 2
The relay is not connected to the target peer.
NoSupport = 3
The target peer does not support the holepunch extension.
NoSelf = 4
The target is the relay peer itself.
Implementations