HolepunchMessage

Struct HolepunchMessage 

pub struct HolepunchMessage {
    pub msg_type: HolepunchMsgType,
    pub addr: SocketAddr,
    pub error_code: u32,
}
A parsed BEP 55 holepunch extension message.

Fields

msg_type: HolepunchMsgType

Message type.

addr: SocketAddr

Target/subject peer address.

error_code: u32

Error code (meaningful only when msg_type == Error).

Implementations

Source

impl HolepunchMessage

pub fn rendezvous(target: SocketAddr) -> Self

Create a Rendezvous message requesting the relay connect us to target.

pub fn connect(addr: SocketAddr) -> Self

Create a Connect message telling a peer to initiate a connection to addr.

pub fn error(addr: SocketAddr, error: HolepunchError) -> Self

Create an Error message for a failed rendezvous.

pub fn to_bytes(&self) -> Bytes

Serialize to binary payload (without the BEP 10 extension header).

pub fn from_bytes(data: &[u8]) -> Result<Self>

Parse from binary payload (after BEP 10 extension header is stripped).

Errors

Returns an error if the data is too short or contains invalid fields.